pub struct Cli {
pub cmd: String,
pub args_templates: Vec<String>,
pub args_separator: String,
pub debug: bool,
pub args_file: Option<PathBuf>,
pub entries: EntriesOptions,
}Fields
cmd: Stringargs_templates: Vec<String>Arguments templates that will be resolved and passed to cmd. Allowed values:
- static text
- {} - all input arguments
- {
} - all input arguments, each splittded by and all parts of split are taken - {
y} - all input arguments, each splittded by and y-th part of split is taken - {x} - x-th argument
- {x
} - x-th argument splittded by and all parts of split are taken - {x
y} - x-th argument splittded by and y-th part of split is taken.
args_separator: StringSeparator between args. Each entry line will be splitted by this separator
debug: boolPrint command with resolved args instead of running it
args_file: Option<PathBuf>Reads arguments from file instead of standard input
entries: EntriesOptionsTrait Implementations
Sourceimpl Args for Cli
impl Args for Cli
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Cli
impl CommandFactory for Cli
Sourceimpl FromArgMatches for Cli
impl FromArgMatches for Cli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for Cli
impl Parser for Cli
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)